@@ -25,9 +25,7 @@ has 'handler';
 
 my $singleton;
 
-sub new {
-  $singleton ||= $_[0] ? shift->SUPER::new(@_) : __PACKAGE__->SUPER::new;
-}
+sub new { $singleton ||= __PACKAGE__->SUPER::new }
 
 sub disable {
   $singleton->_protect(sub { $SIG{CHLD} = $singleton->handler() });
@@ -122,22 +120,17 @@ sub contains {
   $singleton->all->grep(sub { $_->pid eq $pid })->size == 1;
 }
 
-sub reset {
-  $_[0]->{events} = {};
-  $_[0]->orphans({});
-  shift->process_table({});
-}
+sub reset { @{+shift}{qw(events orphans process_table)} = ({}, {}, {}) }
 
+# XXX: This should be replaced by PR_GET_CHILD_SUBREAPER
 sub disable_subreaper {
-  $singleton->subreaper(1)
-    unless $singleton->_prctl(PR_SET_CHILD_SUBREAPER, 0) == 0;
-  $singleton;
+  $singleton->subreaper(
+    $singleton->_prctl(PR_SET_CHILD_SUBREAPER, 0) == 0 ? 0 : 1);
 }
 
 sub enable_subreaper {
-  $singleton->subreaper(0)
-    unless $singleton->_prctl(PR_SET_CHILD_SUBREAPER, 1) == 0;
-  $singleton;
+  $singleton->subreaper(
+    $singleton->_prctl(PR_SET_CHILD_SUBREAPER, 1) == 0 ? 1 : 0);
 }
 
 sub _get_prctl_syscall {
